import { Component, OnInit, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as echarts from 'echarts';
import { AiApiService } from '../../../../lib/ai-api.service';

@Component({
  selector: 'app-page-interview',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './page-interview.html',
  styleUrl: './page-interview.scss'
})
export class PageInterview implements OnInit, AfterViewInit {
  remainingTime = '04:32';
  isAnalyzing = false;
  showSubmitButton = false;
  showCancelButton = false; // 添加缺失的属性
  userAnswer = '';
  isFollowUpQuestion = false; // 添加缺失的属性
  
  // 面试问题相关
  mainQuestions = [
    "欢迎参加本次AI面试,我是您的面试官AI助手。",
    "首先，请简单介绍一下您自己。",
    "您在过去工作中遇到的最大技术挑战是什么？您是如何解决的？",
    "请描述一个您与团队意见不合时，您是如何处理的案例。"
  ];
  
  followUpQuestions = [
    "", // 第一个问题不需要追问
    "您能详细说明一下您最擅长的技术领域吗？",
    "在这个解决方案中，您学到了什么重要的经验？",
    "这次经历如何影响了您后续的团队协作方式？"
  ];
  
  currentQuestionIndex = 0;
  currentQuestion = this.mainQuestions[0];
  showQuestionCard = false;
  progress = 30;
  
  // 对话相关
  messages: {sender: 'ai' | 'user', text: string}[] = [];
  
  // 语音相关
  isListening = false;
  isSpeaking = false;
  
  // 头像和表情相关
  avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f913.svg";
  expressionText = "正在聆听您的回答...";
  
  // 仪表盘相关
  showRadarChart = false;
  metrics = {
    expressiveness: 82,
    professionalism: 65,
    relevance: 73
  };
  
  @ViewChild('dialogContainer') dialogContainer!: ElementRef;
  private radarChart: any;

  constructor(private aiService: AiApiService) {}

  ngOnInit(): void {
    this.initConversation();
    this.startProgressTimer();
  }
  
  ngAfterViewInit(): void {
    this.initRadarChart();
  }
  
  // 添加缺失的方法
  updateAvatarState(state: "speaking" | "listening" | "waiting" | "analyzing"): void {
    switch(state) {
      case "speaking":
        this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f5e3.svg";
        this.expressionText = "正在播报问题...";
        break;
      case "listening":
        this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f4ac.svg";
        this.expressionText = "正在聆听您的回答...";
        break;
      case "waiting":
        this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f914.svg";
        this.expressionText = "请确认您的回答";
        break;
      case "analyzing":
        this.avatarImage = "https://cdn.jsdelivr.net/gh/twitter/twemoji@14.0.2/assets/svg/1f9d0.svg";
        this.expressionText = "正在分析您的回答...";
        break;
    }
  }
  
  initConversation(): void {
    this.addAIMessage(this.mainQuestions[0]);
    setTimeout(() => {
      this.askQuestion(1);
    }, 1500);
  }
  
  askQuestion(index: number): void {
    if (index >= this.mainQuestions.length) {
      this.endInterview();
      return;
    }
    
    this.currentQuestionIndex = index;
    this.isFollowUpQuestion = false;
    this.currentQuestion = this.mainQuestions[index];
    
    this.addAIMessage(this.currentQuestion);
    this.updateAvatarState("speaking");
  }
  
  askFollowUpQuestion(): void {
    if (this.currentQuestionIndex >= this.followUpQuestions.length || 
        !this.followUpQuestions[this.currentQuestionIndex]) {
      this.askQuestion(this.currentQuestionIndex + 1);
      return;
    }
    
    this.isFollowUpQuestion = true;
    this.currentQuestion = this.followUpQuestions[this.currentQuestionIndex];
    
    this.addAIMessage(this.currentQuestion);
    this.updateAvatarState("speaking");
  }
  
  endInterview(): void {
    this.addAIMessage("感谢您的回答，面试即将结束，正在生成最终报告...");
    this.updateAvatarState("analyzing");
  }
  
  addAIMessage(text: string): void {
    this.messages.push({
      sender: 'ai',
      text: text
    });
    
    setTimeout(() => {
      this.dialogContainer.nativeElement.scrollTop = this.dialogContainer.nativeElement.scrollHeight;
    }, 0);
    
    this.speakText(text);
  }
  
  addUserMessage(text: string): void {
    this.messages.push({
      sender: 'user',
      text: text
    });
    
    setTimeout(() => {
      this.dialogContainer.nativeElement.scrollTop = this.dialogContainer.nativeElement.scrollHeight;
    }, 0);
  }
  
  speakText(text: string): void {
    if (this.isSpeaking) return;
    
    this.isSpeaking = true;
    this.updateAvatarState("speaking");
    
    const utterance = new SpeechSynthesisUtterance(text);
    utterance.lang = 'zh-CN';
    utterance.rate = 0.9;
    utterance.pitch = 1;
    
    utterance.onend = () => {
      this.isSpeaking = false;
      this.updateAvatarState("listening");
    };
    
    speechSynthesis.speak(utterance);
  }
  
  startVoiceInput(): void {
    this.isListening = true;
    this.updateAvatarState("listening");
    console.log('语音输入开始');
  }
  
  stopVoiceInput(): void {
    this.isListening = false;
    
    // 模拟语音识别结果
    this.userAnswer = "这是我的回答...";
    this.showSubmitButton = true;
    this.showCancelButton = true;
    
    this.updateAvatarState("waiting");
  }
  
  async submitAnswer(): Promise<void> {
    this.showSubmitButton = false;
    this.showCancelButton = false;
    this.addUserMessage(this.userAnswer);
    
    this.isAnalyzing = true;
    this.updateAvatarState("analyzing");
    
    try {
      const evaluation = await this.aiService.evaluateInterviewAnswer(
        this.currentQuestion,
        this.userAnswer,
        (content) => console.log('分析进度:', content)
      );
      
      this.metrics = {
        expressiveness: evaluation.metrics.expressiveness,
        professionalism: evaluation.metrics.professionalism,
        relevance: evaluation.metrics.relevance
      };
      
      this.addAIMessage(evaluation.feedback);
      
      if (!this.isFollowUpQuestion) {
        this.addAIMessage("接下来，我有一个跟进问题...");
        setTimeout(() => {
          this.currentQuestion = evaluation.followUpQuestion;
          this.isFollowUpQuestion = true;
          this.addAIMessage(this.currentQuestion);
        }, 1500);
      } else {
        setTimeout(() => {
          this.askQuestion(this.currentQuestionIndex + 1);
        }, 1500);
      }
    } catch (error) {
      console.error('评估失败:', error);
      this.addAIMessage("分析完成，让我们继续下一个问题");
      this.askQuestion(this.currentQuestionIndex + 1);
    } finally {
      this.isAnalyzing = false;
      this.userAnswer = '';
    }
  }
  
  cancelAnswer(): void {
    this.showSubmitButton = false;
    this.showCancelButton = false;
    this.userAnswer = '';
    this.updateAvatarState("listening");
  }
  
  playQuestion(): void {
    if (!this.isSpeaking) {
      this.speakText(this.currentQuestion);
    }
  }
  
  toggleRadarChart(): void {
    this.showRadarChart = !this.showRadarChart;
    if (this.showRadarChart) {
      setTimeout(() => {
        this.initRadarChart();
      }, 0);
    }
  }
  
  initRadarChart(): void {
    if (!this.showRadarChart) return;
    
    const chartDom = document.getElementById('radarChart');
    if (!chartDom) return;
    
    if (this.radarChart) {
      this.radarChart.dispose();
    }
    
    this.radarChart = echarts.init(chartDom);
    
    const option = {
      backgroundColor: 'transparent',
      tooltip: {},
      radar: {
        shape: 'circle',
        indicator: [
          { name: '表达能力', max: 100 },
          { name: '专业深度', max: 100 },
          { name: '岗位匹配', max: 100 },
          { name: '应变能力', max: 100 },
          { name: '沟通技巧', max: 100 },
          { name: '知识广度', max: 100 }
        ],
        radius: '65%',
        axisName: {
          color: '#4A5568'
        },
        splitArea: {
          areaStyle: {
            color: ['rgba(42, 92, 170, 0.1)']
          }
        },
        axisLine: {
          lineStyle: {
            color: 'rgba(42, 92, 170, 0.3)'
          }
        },
        splitLine: {
          lineStyle: {
            color: 'rgba(42, 92, 170, 0.3)'
          }
        }
      },
      series: [{
        type: 'radar',
        data: [
          {
            value: [82, 65, 73, 68, 75, 60],
            name: '当前表现',
            areaStyle: {
              color: 'rgba(42, 92, 170, 0.4)'
            },
            lineStyle: {
              width: 2,
              color: 'rgba(42, 92, 170, 0.8)'
            },
            itemStyle: {
              color: '#2A5CAA'
            }
          },
          {
            value: [70, 80, 85, 75, 65, 70],
            name: '岗位要求',
            areaStyle: {
              color: 'rgba(255, 107, 53, 0.2)'
            },
            lineStyle: {
              width: 2,
              color: 'rgba(255, 107, 53, 0.8)'
            },
            itemStyle: {
              color: '#FF6B35'
            }
          }
        ]
      }]
    };
    
    this.radarChart.setOption(option);
    
    window.addEventListener('resize', () => {
      this.radarChart?.resize();
    });
  }
  
  startProgressTimer(): void {
    setInterval(() => {
      this.progress = Math.min(this.progress + 10, 100);
    }, 5000);
  }
}